==> haskell-weigh-0.0.18-114.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 weigh
version:              0.0.18
visibility:           public
id:                   weigh-0.0.18-8dgEZFQWfcq6NNRNkLMZWt
key:                  weigh-0.0.18-8dgEZFQWfcq6NNRNkLMZWt
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  9de65bb730355fb7d88cc37b96a7b77b
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.18-8dgEZFQWfcq6NNRNkLMZWt
depends:
    base-4.18.2.1 criterion-measurement-0.2.3.0-GTVpwTo2u8PcyeGoHvPw3
    deepseq-1.4.8.1 mtl-2.3.1 process-1.6.19.0
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-weigh-0.0.18-115-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 weigh
version:              0.0.18
visibility:           public
id:                   weigh-0.0.18-E8rDw89iJ487c3oUOCrANP
key:                  weigh-0.0.18-E8rDw89iJ487c3oUOCrANP
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  c6bf5daa691d4cee818b4dcff4de3bea
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/weigh-0.0.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.18-E8rDw89iJ487c3oUOCrANP
depends:
    base-4.18.2.1 criterion-measurement-0.2.3.0-gtGIRYSHl9ETYuz9xAQfL
    deepseq-1.4.8.1 mtl-2.3.1 process-1.6.19.0
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
